@@ -1,4 +1,4 @@
-from eveuniverse.models import EveGroup, EveType
+# from eveuniverse.models import EveGroup, EveType
 
 
 class PriceGroups:
@@ -44,6 +44,12 @@ class PriceGroups:
         4514,  # Ytirium
         4515,  # Eifyrium
         4516,  # Ducinium
+        4568,  # Mutanite
+        4755,  # Kylixium
+        4756,  # Nocxite
+        4757,  # Ueganite
+        4758,  # Hezorime
+        4759,  # Griemeer
     )
 
     taxgroups = {
@@ -63,10 +69,10 @@ class PriceGroups:
         467: "Ores",
         454: "Ores",
         455: "Ores",
-        529: "Ores",
+        # 529: "Ores",
         457: "Ores",
-        526: "Ores",
-        516: "Ores",
+        # 526: "Ores",
+        # 516: "Ores",
         458: "Ores",
         459: "Ores",
         4030: "Ores",
@@ -79,23 +85,31 @@ class PriceGroups:
         4514: "Ores",
         4515: "Ores",
         4516: "Ores",
+        456: "Ores",  # Jaspet
+        4568: "Ores",  # Mutanite
+        4755: "Ores",  # Kylixium
+        4756: "Ores",  # Nocxite
+        4757: "Ores",  # Ueganite
+        4758: "Ores",  # Hezorime
+        4759: "Ores",  # Griemeer
     }
 
-    def __init__(self):
-        self.items = []
-        added = set()
-        for grp in self.groups:
-            EveGroup.objects.update_or_create_esi(
-                id=grp,
-                include_children=True,
-                wait_for_children=True,
-            )
-            g = EveType.objects.filter(eve_group_id=grp)
-            for it in g:
-                if it.id in added:
-                    continue
-                added.add(it.id)
-                self.items.append(it)
-        self.taxable_groups = set()
-        for k in self.taxgroups.keys():
-            self.taxable_groups.add(self.taxgroups[k])
+
+#    def __init__(self):
+#        self.items = []
+#        added = set()
+#        for grp in self.groups:
+#            EveGroup.objects.get_or_create_esi(
+#                id=grp,
+#                include_children=True,
+#                wait_for_children=True,
+#            )
+#            g = EveType.objects.filter(eve_group_id=grp)
+#            for it in g:
+#                if it.id in added:
+#                    continue
+#                added.add(it.id)
+#                self.items.append(it)
+#        self.taxable_groups = set()
+#        for k in self.taxgroups.keys():
+#            self.taxable_groups.add(self.taxgroups[k])
