@@ -1,5 +1,6 @@
 from django.core.management.base import BaseCommand
 
+from ...models import Stats
 from ...tasks import update_all_prices
 
 
@@ -8,3 +9,5 @@ class Command(BaseCommand):
 
     def handle(self, *args, **options):
         update_all_prices()
+        s = Stats.load()
+        s.calc_ore_prices_json()
