@@ -8,7 +8,7 @@ from django.contrib.auth.models import User
 from django.core.exceptions import ObjectDoesNotExist
 from django.core.serializers.json import DjangoJSONEncoder
 from django.db import models
-from django.db.models import Sum
+from django.db.models import Case, Sum, Value, When
 from django.db.models.functions import TruncMonth
 from django.utils.functional import cached_property
 from django.utils.timezone import now
@@ -26,9 +26,16 @@ from app_utils.logging import LoggerAddTag
 from .. import __title__
 from ..app_settings import (
     MININGTAXES_BLACKLIST,
+    MININGTAXES_LEADERBOARD_TAXABLE_ONLY,
+    MININGTAXES_TAX_HISEC,
+    MININGTAXES_TAX_JSPACE,
+    MININGTAXES_TAX_LOSEC,
+    MININGTAXES_TAX_NULLSEC,
     MININGTAXES_TAX_ONLY_CORP_MOONS,
+    MININGTAXES_TAX_POCHVEN,
     MININGTAXES_UPDATE_LEDGER_STALE,
     MININGTAXES_UPDATE_STALE_OFFSET,
+    MININGTAXES_WHITELIST,
 )
 from ..decorators import fetch_token_for_character
 from ..helpers import PriceGroups
@@ -229,13 +236,25 @@ class Character(CharacterAbstract):
             eve_solar_system, _ = EveSolarSystem.objects.get_or_create_esi(
                 id=entry["solar_system_id"]
             )
-            (row, _) = self.mining_ledger.update_or_create(
-                date=entry["date"],
-                eve_solar_system=eve_solar_system,
-                eve_type=eve_type,
-                defaults={"quantity": entry["quantity"]},
-            )
-            row.calc_prices()
+            try:
+                row = self.mining_ledger.get(
+                    date=entry["date"],
+                    eve_solar_system=eve_solar_system,
+                    eve_type=eve_type,
+                )
+                if row.quantity != entry["quantity"]:
+                    row.quantity = entry["quantity"]
+                    row.save()
+                    row.calc_prices()
+            except CharacterMiningLedgerEntry.DoesNotExist:
+                row = self.mining_ledger.create(
+                    date=entry["date"],
+                    eve_solar_system=eve_solar_system,
+                    eve_type=eve_type,
+                    quantity=entry["quantity"],
+                )
+                row.calc_prices()
+
         self.calc_lifetime_taxes()
         self.calc_monthly_taxes()
         self.calc_monthly_mining()
@@ -328,13 +347,30 @@ class Character(CharacterAbstract):
         return self.standardize(self.monthly_credits_json)
 
     def calc_monthly_mining(self):
-        dat = (
-            self.mining_ledger.all()
-            .annotate(month=TruncMonth("date"))
-            .values("month")
-            .annotate(total=Sum("taxed_value"))
-            .order_by("month")
-        )
+        if MININGTAXES_LEADERBOARD_TAXABLE_ONLY:
+            dat = (
+                self.mining_ledger.all()
+                .annotate(month=TruncMonth("date"))
+                .values("month")
+                .annotate(
+                    total=Sum(
+                        Case(
+                            When(taxes_owed__gt=0, then="taxed_value"),
+                            default=Value(0),
+                            output_field=models.FloatField(),
+                        )
+                    )
+                )
+                .order_by("month")
+            )
+        else:
+            dat = (
+                self.mining_ledger.all()
+                .annotate(month=TruncMonth("date"))
+                .values("month")
+                .annotate(total=Sum("taxed_value"))
+                .order_by("month")
+            )
 
         self.monthly_mining_json = self.json_standardize(dat)
         self.save()
@@ -527,8 +563,8 @@ class CharacterMiningLedgerEntry(models.Model):
         return f"{self.character} {self.id}"
 
     def calc_prices(self):
-        if self.raw_price != 0.0:
-            return
+        # if self.raw_price != 0.0:
+        #    return
         self.raw_price, self.refined_price, self.taxed_value = ore_calc_prices(
             self.eve_type, self.quantity
         )
@@ -537,6 +573,30 @@ class CharacterMiningLedgerEntry(models.Model):
         self.refined_price = round(self.refined_price, 2)
         self.taxed_value = round(self.taxed_value, 2)
         self.taxes_owed = round(self.taxes_owed, 2)
-        if self.eve_solar_system.name in MININGTAXES_BLACKLIST:
+        if (
+            len(MININGTAXES_WHITELIST) > 0
+            and self.eve_solar_system.name not in MININGTAXES_WHITELIST
+        ) or (
+            len(MININGTAXES_WHITELIST) == 0
+            and (
+                self.eve_solar_system.name in MININGTAXES_BLACKLIST
+                or (
+                    MININGTAXES_TAX_HISEC is False and self.eve_solar_system.is_high_sec
+                )
+                or (MININGTAXES_TAX_LOSEC is False and self.eve_solar_system.is_low_sec)
+                or (
+                    MININGTAXES_TAX_NULLSEC is False
+                    and self.eve_solar_system.is_null_sec
+                )
+                or (
+                    MININGTAXES_TAX_JSPACE is False and self.eve_solar_system.is_w_space
+                )
+                or (
+                    MININGTAXES_TAX_POCHVEN is False
+                    and self.eve_solar_system.is_trig_space
+                )
+            )
+        ):
             self.taxes_owed = 0.0
+
         self.save()
