@@ -12,22 +12,17 @@ from ..app_settings import (
     MININGTAXES_REFINED_RATE,
     MININGTAXES_UNKNOWN_TAX_RATE,
 )
-from ..helpers import PriceGroups
-from .settings import Settings
 
 logger = LoggerAddTag(get_extension_logger(__name__), __title__)
 
 
 def get_tax(eve_type):
-    settings = Settings.load()
-    pg = PriceGroups()
-    if eve_type.eve_group_id not in pg.taxgroups:
-        logger.debug(
-            "Unknown evetype for %s, group: %d" % (eve_type, eve_type.eve_group_id)
-        )
-        return MININGTAXES_UNKNOWN_TAX_RATE
-    group = "tax_" + pg.taxgroups[eve_type.eve_group_id]
-    return settings.__dict__[group] / 100.0
+    try:
+        ore = OrePrices.objects.get(eve_type=eve_type)
+        return ore.tax_rate / 100.0
+    except OrePrices.DoesNotExist:
+        pass
+    return MININGTAXES_UNKNOWN_TAX_RATE
 
 
 def ore_calc_prices(eve_type, q):
@@ -86,6 +81,7 @@ class OrePrices(models.Model):
     raw_price = models.FloatField(default=0.0)
     refined_price = models.FloatField(default=0.0)
     taxed_price = models.FloatField(default=0.0)
+    tax_rate = models.FloatField(default=10.0)
     updated = models.DateTimeField()
 
     def calc_prices(self):
@@ -93,6 +89,12 @@ class OrePrices(models.Model):
         materials = EveTypeMaterial.objects.filter(
             eve_type_id=self.eve_type.id
         ).prefetch_related("eve_type")
+        if len(materials) == 0:  # try once if can't find materials in case of new ore
+            EveTypeMaterial.objects.update_or_create_api(eve_type=self.eve_type)
+            materials = EveTypeMaterial.objects.filter(
+                eve_type_id=self.eve_type.id
+            ).prefetch_related("eve_type")
+
         self.refined_price = 0.0
         for mat in materials:
             q = MININGTAXES_REFINED_RATE * mat.quantity / self.eve_type.portion_size
