@@ -127,6 +127,45 @@ def apply_interest(self):
             notify(user=u, title=title, message=message, level="WARN")
 
 
+@shared_task(**{**TASK_DEFAULT_KWARGS, **{"bind": True}})
+def auto_add_chars(self):
+    from django.db import transaction
+    from esi.models import Token
+
+    scopes = Character.get_esi_scopes()
+    tracked_corps = set()
+
+    for achar in AdminCharacter.objects.all():
+        tracked_corps.add(achar.eve_character.corporation_id)
+
+    for char in EveCharacter.objects.all():
+        # check if in plugin already
+        try:
+            inplug = Character.objects.get(eve_character=char)
+            inplug = True
+        except Character.DoesNotExist:
+            inplug = False
+            pass
+        if inplug:
+            continue
+        # check if in tracked corp
+        if char.corporation_id not in tracked_corps:
+            continue
+        # check if has token for esi scope
+        token = Token.get_token(char.character_id, scopes)
+        if not token:
+            continue
+        # check if orphaned and find user
+        try:
+            u = char.userprofile
+        except EveCharacter.userprofile.RelatedObjectDoesNotExist:
+            continue
+        logger.info(f"Need to add {char} to miningtaxes, user: {u}")
+        with transaction.atomic():
+            mcharacter, _ = Character.objects.update_or_create(eve_character=char)
+        update_character(character_pk=mcharacter.pk)
+
+
 @shared_task(**{**TASK_DEFAULT_KWARGS, **{"bind": True}})
 def update_daily(self):
     logger.info("Beginning price update")
@@ -422,7 +461,7 @@ def add_tax_credits():
                         character_id=entry.taxed_id
                     ).pk,
                 )
-            except EveCharacter.DoesNotExist:
+            except Character.DoesNotExist:
                 payee = get_user(entry.taxed_id)
                 if payee is None:
                     continue
