@@ -70,6 +70,16 @@ urlpatterns = [
     path("ore_prices_json", views.ore_prices_json, name="ore_prices_json"),
     path("leaderboards", views.leaderboards, name="leaderboards"),
     path("admin/", views.admin_launcher, name="admin_launcher"),
+    path(
+        "admin_tax_table",
+        views.admin_launcher_tax_table,
+        name="admin_launcher_tax_table",
+    ),
+    path(
+        "admin_launcher_save_rates",
+        views.admin_launcher_save_rates,
+        name="admin_launcher_save_rates",
+    ),
     path("admin/tables", views.admin_tables, name="admin_tables"),
     path("admin_main_json", views.admin_main_json, name="admin_main_json"),
     path("admin_char_json", views.admin_char_json, name="admin_char_json"),
