@@ -35,8 +35,10 @@ logger = LoggerAddTag(get_extension_logger(__name__), __title__)
 @login_required
 @permission_required("miningtaxes.admin_access")
 def admin_launcher(request):
+    logger.debug("HERE")
     settings = Settings.load()
     if request.method == "POST":
+        logger.debug("HERE2")
         form = SettingsForm(request.POST)
         if form.is_valid():
             form = SettingsForm(request.POST, instance=settings)
@@ -91,6 +93,53 @@ def admin_launcher(request):
     return render(request, "miningtaxes/admin_launcher.html", context)
 
 
+@login_required
+@permission_required("miningtaxes.admin_access")
+def admin_launcher_tax_table(request):
+    from .helpers import PriceGroups
+    from .models import OrePrices
+
+    data = []
+    pg = PriceGroups()
+    for ore in OrePrices.objects.all():
+        if "Compressed" in ore.eve_type.name:
+            continue
+        if ore.eve_type.eve_group_id not in pg.taxgroups:
+            continue
+        tax_rate = ore.tax_rate
+        group = pg.taxgroups[ore.eve_type.eve_group_id]
+        data.append(
+            {
+                "group": group,
+                "name": ore.eve_type.name,
+                "tid": ore.id,
+                "tax_rate": tax_rate,
+            }
+        )
+    return JsonResponse({"data": data})
+
+
+@login_required
+@permission_required("miningtaxes.admin_access")
+def admin_launcher_save_rates(request):
+    import json
+
+    from .models import OrePrices
+
+    s = Stats.load()
+    data = json.loads(request.POST["tax_data"])
+    for d in data:
+        ore = OrePrices.objects.get(id=d["tid"])
+        ore.tax_rate = d["tax_rate"]
+        ore.save()
+    messages.info(
+        request,
+        format_html("Tax rates updated!"),
+    )
+    s.calc_ore_prices_json()
+    return redirect("miningtaxes:admin_launcher")
+
+
 @login_required
 @permission_required("miningtaxes.auditor_access")
 def admin_char_json(request):
@@ -285,6 +334,8 @@ def summary_month_json(request, user_pk: int):
         y = [characters[i].name]
         x = ["x"]
         curmonth = firstmonth
+        if curmonth is None:
+            continue
         lastmonth = dt.date(now().year, now().month, 1)
         while curmonth <= lastmonth:
             if curmonth not in entries:
@@ -574,14 +625,14 @@ def char_mining_ledger_data(request, character_pk: int) -> JsonResponse:
 
 
 @login_required
-@permission_required("memberaudit.basic_access")
+@permission_required("miningtaxes.basic_access")
 def curmonthgraph(request) -> JsonResponse:
     s = Stats.load()
     return JsonResponse(s.get_curmonth_leadergraph())
 
 
 @login_required
-@permission_required("memberaudit.basic_access")
+@permission_required("miningtaxes.basic_access")
 def user_mining_ledger_90day(request, user_pk: int) -> JsonResponse:
     user = User.objects.get(pk=user_pk)
     if request.user != user and not request.user.has_perm("miningtaxes.auditor_access"):
